package com.chelvc.cloud.maintain.controller;

import java.util.List;
import javax.validation.Valid;
import javax.validation.constraints.Min;

import com.chelvc.cloud.vehicle.client.HotMerchantClient;
import com.chelvc.cloud.vehicle.client.dto.MerchantDTO;
import com.chelvc.cloud.vehicle.client.param.LocationQueryParam;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * 热门搜索接口
 *
 * @author liude
 * @date 2023/12/20
 */
@Validated
@RestController
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class HotMerchantController {
    private final HotMerchantClient hotMerchantClient;

    /**
     * 添加用户点击埋点
     *
     * @param
     */
    @GetMapping("/hotMerchant/{id}")
    public void addHotMerchant(@PathVariable("id") @Min(value = 1, message = "商品ID不能小于1") Long id) {
        this.hotMerchantClient.addHotMerchant(id);
    }


    /**
     * 热门搜索商家
     *
     * @param
     */
    @PostMapping("/listHotMerchant/")
    public List<MerchantDTO> listHotMerchant(@Valid @RequestBody LocationQueryParam param) {
        param.setCode((param.getRegion()/100)*100);
        param.setBoundary((param.getRegion()/100)*100+99);
        return this.hotMerchantClient.listHotMerchant(param);
    }

    /**
     * 猜你喜欢的商家
     *
     * @param
     */
    @PostMapping("/likeMerchant/")
    public List<MerchantDTO> likeMerchant(@Valid @RequestBody LocationQueryParam param) {
        param.setCode((param.getRegion()/100)*100);
        param.setBoundary((param.getRegion()/100)*100+99);
        return this.hotMerchantClient.likeMerchant(param);
    }


}
