package com.chelvc.cloud.maintain.controller;

import javax.validation.Valid;

import com.chelvc.cloud.vehicle.client.UserInviteClient;
import com.chelvc.cloud.vehicle.client.dto.TeamDTO;
import com.chelvc.cloud.vehicle.client.param.TeamInvitePageParam;
import com.chelvc.cloud.vehicle.client.param.UserInviteParams;
import com.chelvc.framework.base.annotation.ResponseWrapping;
import com.chelvc.framework.base.context.SessionContextHolder;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 用户邀请接口
 */
@Validated
@RestController
@RequestMapping("/invite")
@ResponseWrapping
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class UserInviteController {
    private final UserInviteClient userInviteClient;

    /**
     * 绑定关系
     *
     * @param param
     * @author igl
     * @date 2024/2/23 17:25
     */
    @PostMapping("/bind")
    public void bindInvite(@Validated @RequestBody UserInviteParams param) {
        this.userInviteClient.bindInvite(param);
    }

    /**
     * 我的团队
     *
     * @param param 类型：1-用户；2-商家；不传值-查所有
     * @author igl
     * @date 2024/2/26 10:12
     */
    @GetMapping("/team/page")
    public TeamDTO teamList(@Valid TeamInvitePageParam param) {
        return this.userInviteClient.teamList(param, SessionContextHolder.getId());
    }
}
